@@ -36,7 +36,7 @@ from __future__ import absolute_import, print_function
 import copy
 import sys
 import re
-from typing import TYPE_CHECKING, Any, Callable, Container, Iterable, List, Match, Optional, Tuple, Type, Union  # noqa F401
+from typing import TYPE_CHECKING, Any, Callable, Container, Iterable, List, Match, Optional, Tuple, Type, Union  # noqa: F401
 
 import six
 from ldap.filter import filter_format
@@ -46,7 +46,7 @@ import univention.config_registry
 import univention.debug as ud
 from univention.admin._ucr import configRegistry
 if TYPE_CHECKING:
-	from univention.admin.layout import Tab  # noqa F401
+	from univention.admin.layout import Tab  # noqa: F401
 
 
 __all__ = ('configRegistry', 'ucr_overwrite_properties', 'pattern_replace', 'property', 'option', 'ucr_overwrite_module_layout', 'ucr_overwrite_layout', 'extended_attribute', 'policiesGroup', 'modules', 'objects', 'syntax', 'hook', 'mapping')
@@ -98,7 +98,7 @@ def ucr_overwrite_properties(module, lo):
 							syntax = getattr(univention.admin.syntax, new_prop_val)
 							setattr(prop, attr, syntax())
 						else:
-							if lo.search(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [new_prop_val])):
+							if lo.searchDn(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [new_prop_val])):
 								syntax = univention.admin.syntax.LDAP_Search(new_prop_val)
 								syntax._load(lo)
 								setattr(prop, attr, syntax)
@@ -624,7 +624,7 @@ class policiesGroup:
 
 
 univention.admin = sys.modules[__name__]
-from univention.admin import modules, objects, syntax, hook, mapping  # noqa
+from univention.admin import modules, objects, syntax, hook, mapping  # noqa: F401
 syntax.import_syntax_files()
 hook.import_hook_files()
 
