@@ -52,15 +52,11 @@ object_name = _('IMAP mail folder')
 object_name_plural = _('IMAP mail folders')
 long_description = ''
 
-module_search_filter = univention.admin.filter.conjunction('&', [
-	univention.admin.filter.expression('objectClass', 'univentionMailSharedFolder'),
-])
 
+class MailDomain(univention.admin.syntax.UDM_Attribute):
+	udm_module = 'mail/domain'
+	attribute = 'name'
 
-ldap_search_maildomain = univention.admin.syntax.LDAP_Search(
-	filter='(objectClass=univentionMailDomainname)',
-	attribute=['mail/domain: name'],
-	value='mail/domain: name')
 
 options = {
 	'default': univention.admin.option(
@@ -83,7 +79,7 @@ property_descriptions = {
 	'mailDomain': univention.admin.property(
 		short_description=_('Mail domain'),
 		long_description='',
-		syntax=ldap_search_maildomain,
+		syntax=getattr(univention.admin.syntax, 'MailDomain', MailDomain),
 		include_in_default_search=True,
 		required=True,
 		may_change=False,
@@ -213,7 +209,7 @@ class object(univention.admin.handlers.simpleLdap):
 				))
 
 				address = '%s@%s' % (self['name'], self['mailDomain'])
-				if self['mailPrimaryAddress'] != address:
+				if self['mailPrimaryAddress'] != address and self['mailPrimaryAddress'].lower() != self.oldinfo.get('mailPrimaryAddress', '').lower():
 					try:
 						self.request_lock('mailPrimaryAddress', self['mailPrimaryAddress'])
 					except univention.admin.uexceptions.noLock:
@@ -260,4 +256,5 @@ class object(univention.admin.handlers.simpleLdap):
 
 
 lookup = object.lookup
+lookup_filter = object.lookup_filter
 identify = object.identify
