@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -312,7 +312,7 @@ class object(univention.admin.handlers.simpleLdap):
 		olddn = self.dn
 		tmpdn = u'cn=%s-subtree,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(self['username']), self.lo.base)
 		al = [('objectClass', [b'top', b'organizationalRole']), ('cn', [b'%s-subtree' % self['username'].encode('UTF-8')])]
-		subelements = self.lo.search(base=self.dn, scope='one', attr=[b'objectClass'])  # FIXME: identify may fail, but users will raise decode-exception
+		subelements = self.lo.search(base=self.dn, scope='one', attr=['objectClass'])  # FIXME: identify may fail, but users will raise decode-exception
 		if subelements:
 			try:
 				self.lo.add(tmpdn, al)
