@@ -1200,6 +1200,7 @@ def unmapSambaRid(oldattr):
 
 def mapKeyAndValue(old, encoding=()):
 	"""Map (key, value) list to key=value list.
+
 	>>> mapKeyAndValue([("a", "b")])
 	[b'a=b']
 	"""
@@ -1208,6 +1209,7 @@ def mapKeyAndValue(old, encoding=()):
 
 def unmapKeyAndValue(old, encoding=()):
 	"""Map (key=value) list to (key, value) list.
+
 	>>> unmapKeyAndValue([b"a=b"])
 	[['a', 'b']]
 	"""
@@ -1528,7 +1530,8 @@ class object(univention.admin.handlers.simpleLdap):
 		self.info['certificateDateNotAfter'] = ''
 		self.info['certificateVersion'] = ''
 		self.info['certificateSerial'] = ''
-		certificate = self.info.get('userCertificate')
+		_certificate = self.info.get('userCertificate')
+		certificate = _certificate[0] if isinstance(_certificate, list) else _certificate
 		values = load_certificate(certificate)
 		if values:
 			self.info.update(values)
@@ -1672,9 +1675,6 @@ class object(univention.admin.handlers.simpleLdap):
 		super(object, self)._ldap_pre_create()
 		ud.debug(ud.ADMIN, ud.INFO, 'users/user: dn was set to %s' % (self.dn,))
 
-		if self['mailPrimaryAddress']:
-			self['mailPrimaryAddress'] = self['mailPrimaryAddress'].lower()
-
 		# request a new uidNumber or get lock for manually set uidNumber
 		if self['uidNumber']:
 			univention.admin.allocators.acquireUnique(self.lo, self.position, 'uidNumber', self['uidNumber'], 'uidNumber', scope='base')
@@ -1698,7 +1698,7 @@ class object(univention.admin.handlers.simpleLdap):
 			if self['primaryGroup'] and not self.lo.getAttr(self['primaryGroup'], 'sambaSID'):
 				raise univention.admin.uexceptions.primaryGroupWithoutSamba(self['primaryGroup'])
 
-		if not self.exists() or self.hasChanged('username'):
+		if not self.exists() or self.hasChanged('username') and self['username'].lower() != self.oldinfo['username'].lower():
 			check_prohibited_username(self.lo, self['username'])
 
 			# get lock for username
@@ -1710,6 +1710,9 @@ class object(univention.admin.handlers.simpleLdap):
 
 		# get lock for mailPrimaryAddress
 		if not self.exists() or self.hasChanged('mailPrimaryAddress'):
+			if self['mailPrimaryAddress']:
+				self['mailPrimaryAddress'] = self['mailPrimaryAddress'].lower()
+
 			# ignore case in change of mailPrimaryAddress, we only store the lowercase address anyway
 			if self['mailPrimaryAddress'] and self['mailPrimaryAddress'].lower() != (self.oldinfo.get('mailPrimaryAddress', None) or '').lower():
 				try:
@@ -1761,10 +1764,6 @@ class object(univention.admin.handlers.simpleLdap):
 		if not self.oldattr.get('mailForwardCopyToSelf') and self['mailForwardCopyToSelf'] == '0' and not self['mailForwardAddress']:
 			self['mailForwardCopyToSelf'] = None
 
-		if self.hasChanged('mailPrimaryAddress'):
-			if self['mailPrimaryAddress']:
-				self['mailPrimaryAddress'] = self['mailPrimaryAddress'].lower()
-
 		if self.hasChanged("uidNumber"):
 			# this should never happen, as uidNumber is marked as unchangeable
 			self._check_uid_gid_uniqueness()
