@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -48,11 +48,8 @@ _ = translation.translate
 
 _license = None
 
-LDAP_FILTER_not_root = '(!(uidNumber=0))'
-LDAP_FILTER_not_machine = '(!(uid=*$))'
-LDAP_FILTER_user_account = '(|(&(objectClass=posixAccount)(objectClass=shadowAccount))(objectClass=sambaSamAccount))'
-LDAP_FILTER_normal_user_account = '(&%s)' % ''.join([LDAP_FILTER_user_account, LDAP_FILTER_not_root, LDAP_FILTER_not_machine])
-LDAP_FILTER_account_not_disabled = '(!(&(shadowExpire=1)(krb5KDCFlags=254)(|(sambaAcctFlags=[UD       ])(sambaAcctFlags=[ULD       ]))))'
+LDAP_FILTER_normal_user_account = '(univentionObjectType=users/user)'
+LDAP_FILTER_account_not_disabled = '(!(&(shadowExpire=1)(krb5KDCFlags:1.2.840.113556.1.4.803:=128)(|(sambaAcctFlags=[UD       ])(sambaAcctFlags=[ULD       ]))))'
 LDAP_FILTER_managedclients = '(|(objectClass=univentionWindows)(objectclass=univentionUbuntuClient)(objectClass=univentionLinuxClient)(objectClass=univentionCorporateClient)(objectClass=univentionMacOSClient))'
 
 
