@@ -35,11 +35,10 @@
 from __future__ import absolute_import
 
 import os
-import sys
 import copy
 import locale
 import importlib
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Text, Tuple, Union  # noqa F401
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Text, Tuple, Union  # noqa: F401
 
 import six
 import ldap
@@ -407,7 +406,7 @@ def update_extended_attributes(lo, module, position):
 		if propertySyntaxString and hasattr(univention.admin.syntax, propertySyntaxString):
 			propertySyntax = getattr(univention.admin.syntax, propertySyntaxString)
 		else:
-			if lo.search(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [propertySyntaxString])):
+			if lo.searchDn(filter=filter_format(univention.admin.syntax.LDAP_Search.FILTER_PATTERN, [propertySyntaxString])):
 				propertySyntax = univention.admin.syntax.LDAP_Search(propertySyntaxString)
 			else:
 				propertySyntax = univention.admin.syntax.string()
