@@ -31,11 +31,11 @@
 |UDM| policy utilities
 """
 
-from typing import Any, Dict, Tuple  # noqa F401
+from typing import Any, Dict, Tuple  # noqa: F401
 
 import univention.admin.localization
 import univention.admin.syntax
-from univention.admin.mapping import ListToString, mapping as MappingType  # noqa F401
+from univention.admin.mapping import ListToString, mapping as MappingType  # noqa: F401
 from univention.admin.layout import Tab
 
 translation = univention.admin.localization.translation('univention.admin')
